*--------------------------------------------------------------------------*;
%let ProgramName = _1_Test_format_cahps50 ;
%let Extension   = sas ;
%let Filename    = &ProgramName..&Extension ;
%let Version     = 5.0 ;
%let Root        = /data/cahps/analysis_program/version5.0/ ; /*add directory*/
%let ProgramPath = /programs/ ; /*add directory where your program is located*/
%let Created     = /*created date here*/ ;
%let Modified    = /*modified date here*/ ;
%let Author      = /*your name here*/ ;
%let Type        = Program ;

*--------------------------------------------------------------------------*
| What are the required input data sets and macros needed by the program.  |
      NONE
*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
| What are the permanent output datasets created by the program or where   |
| are all the datasets stored if there are many.                           |
      formats.sas7bcat
*--------------------------------------------------------------------------*;
 
***********
* Purpose *
   Create permanent formats for the test data set included with
   the CAHPS Analysis Program.

*--------------------------------------------------------------------------*;
%let Updated  = dd-mmm-yyyy ;
%let By_Whom  = ;
**********
* Reason *

*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
| Set up the environment, library names, file names, options...            |
*--------------------------------------------------------------------------*;
libname in        "&root./data/" ;

*--------------------------------------------------------------------------*
|  Macro Name : nowbox                                                     |
|  Usage      : %nowbox (logtext = Your text here)                         |
|  Purpose    :                                                            |
|     Assign the local variable &now the current system date and time      |
|     and place a time stamp line into the current log.                    |
*--------------------------------------------------------------------------*;

%macro nowbox (logtext= ** Time Stamp **) ;
   %local now ;
   %let now = %sysfunc(date(),worddatx32.) at %sysfunc(time(),time9.) ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
   %put &logtext &now ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
%mend nowbox ;


%nowbox (logtext= Begin &FileName version &Version ) ;

*--------------------------------------------------------------------------*
| Global Options Assigned Below                                            |
*--------------------------------------------------------------------------*;

options pagesize = 65
        linesize = 90
        pageno   = 1
        noovp
        nonumber
        nodate
        nomprint
        nomlogic
        fmtsearch = (in)
;

*--------------------------------------------------------------------------*
| Clear titles and footnotes.                                              |
*--------------------------------------------------------------------------*;

title ;
footnote;

*--------------------------------------------------------------------------*
| Begin Programming Code                                                   |
*--------------------------------------------------------------------------*;

proc format library = in ; /*place the library name where you want to store the format*/
           
           
 title "CAHPS Survey Formats for TEST Data Set Version &version " ;

  value ynb
         . = ' .: Missing         '
         1 = ' 1: Yes             '
         2 = ' 2: No              '
        98 = '98: Inapplicable    '
        99 = '99: No Answer Given '
  ;
  value yna
         . = ' .: Missing         '
         1 = ' 1: Yes             '
         0 = ' 0: No              '
        98 = '98: Inapplicable    '
        99 = '99: No Answer Given '
  ;
  value triprob
         . = ' .: Missing         '
         1 = ' 1: A Big Problem   '
         2 = ' 2: A Small Problem '
         3 = ' 3: Not a Problem   '
        98 = '98: Inapplicable    '
        99 = '99: No Answer Given '
  ;
  value often
         . = ' .: Missing         '
         1 = ' 1: Never           '
         2 = ' 2: Sometimes       '
         3 = ' 3: Usually         '
         4 = ' 4: Always          '
        98 = '98: Inapplicable    '
        99 = '99: No Answer Given '
  ;
  value rating
         . = 'Missing         '
         0 = '0, worst        '
         1 = '1               '
         2 = '2               '
         3 = '3               '
         4 = '4               '
         5 = '5               '
         6 = '6               '
         7 = '7               '
         8 = '8               '
         9 = '9               '
        10 = '10, best        '
        98 = '98, Inapplicable    '
        99 = '99, No Answer Given '
  ;
  value times
         . = ' .: Missing         '
         0 = ' 0: None            '
         1 = ' 1: 1 time          '
         2 = ' 2: 2 times         '
         3 = ' 3: 3 times         '
         4 = ' 4: 4 times         '
         5 = ' 5: 5 to 9 times    '
         6 = ' 6: 10 or more times'
        98 = '98: Inapplicable    '
        99 = '99: No Answer Given '
  ;
  value ratinge
         . = ' .: Missing         '
         1 = ' 1: Excellent       '
         2 = ' 2: Very good       '
         3 = ' 3: Good            '
         4 = ' 4: Fair            '
         5 = ' 5: Poor            '
        98 = '98: Inapplicable    '
        99 = '99: No Answer Given '
  ;
  value age
         . = ' .: Missing         '
         1 = ' 1: 18 to 24        '
         2 = ' 2: 25 to 34        '
         3 = ' 3: 35 to 44        '
         4 = ' 4: 45 to 54        '
         5 = ' 5: 55 or 64        '
         6 = ' 6: 65 to 74        '
         7 = ' 7: 75 or older     '
        98 = '98: Inapplicable    '
        99 = '99: No Answer Given '
  ;
  value edu
        1=' 1: <= 8TH GRADE'
        2=' 2: SOME HS'
        3=' 3: HS GRAD/GED'
        4=' 4: SOME COLLEGE/2-YR DEGREE'
        5=' 5: 4-YR COLLEGE GRAD'
        6=' 6: >4-YR COLLEGE DEGREE'
       98="98: DON'T KNOW"
       99='99: REFUSED'
  ;     
  value gender
         . = ' .: Missing         '
         1 = ' 1: Male            '
         2 = ' 2: Female          '
        98 = '98: Inapplicable    '
        99 = '99: No Answer Given '
  ;
  value plan
         . = ' .: Missing         '
         1 = ' 1: PRACTICE_A_Urban     '
         2 = ' 2: PRACTICE_B_Urban     '
         3 = ' 3: PRACTICE_C_Urban     '
         4 = ' 4: PRACTICE_B_Rural     '
         5 = ' 5: PRACTICE_C_Rural     '
  ;
run;


*--------------------------------------------------------------------------*
| End Programming Code                                                     |
| Clear titles and footnotes.                                              |
| Reset the log file and output file to their defaults.                    |
| Clear the filenames used.                                                |
*--------------------------------------------------------------------------*;

title ;
footnote;


%nowbox (logtext = End &FileName version &Version ) ;
