*--------------------------------------------------------------------------*;
%let ProgramName = _2_Test_prepdata_cahps50 ;
%let Extension   = sas ;
%let Filename    = &ProgramName..&Extension ;
%let Version     = 5.0 ;
%let Root        = /data/cahps/analysis_program/version5.0 ; /*add directory*/
%let ProgramPath = /programs/ ; /*add directory where your program is located*/
%let Created     = /*created date here*/ ;
%let Modified    = /*modified date here*/ ;
%let Author      = /*your name here*/ ;
%let Type        = Program ;

*--------------------------------------------------------------------------*
| What are the required input data sets and macros needed by the program.  |
|      MACROS: Macro_cahps50.sas                                           |
|      DATA  : Test_cahps50_data.sas7bdat                                  |
|                                                                          |
| Test_cahps50_data.sas7bdat is a test dataset used for this program.      |
| Please note that the data is fictitious. The content is listed below.    |
|                                                                          |  
| q05-Make appointment for routine care                                    |
| q06-Get appt for routine care as soon as wanted                          |
| q11-Provider Explains things                                             |
| q12-Provider Listens carefully                                           |
| q14-Provider Shows respect                                               |
| q15-Provider Spends enough time                                          |
| q18-Rating of Provider                                                   |
| q23-Rate General Health                                                  |
| q24-Rate Mental Helath                                                   |
| q25-Age category                                                         |
| q26-Gender                                                               |
| q27-Highest education level completed                                    |
*--------------------------------------------------------------------------*;

***********
* Purpose *
     Program to test the functionality of the CAHPS Analysis Program 5.0.  
     The data set, test, contains fictitious data for Dichotomous, Overall Rating
     scale (0 - 10), How Often scale (1 - 4), Problem Scale (1 - 3) and
     adjuster variables.  

     It prepares the data set by cleaning, reverse coding and adding
     variables that are needed by the CAHPS macro program.  After the preparation,
     several CAHPS macro calls are made for each type of variable,
     Dichotomous, Overall Rating, How Often and Problem Scales.

*--------------------------------------------------------------------------*;
%let Updated  = dd-mmm-yyyy ;
%let By_Whom  = ;
**********
* Reason *

*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
|  Library and Filename References                                         |
|     in       -  SAS data set to be used as input.                        |
|     ** OUT is required by the CAHPS macro **                             |
|     out      -  Permanent SAS data sets created by Macro stored here.    |
|     library  -  Formats are stored.                                      |
*--------------------------------------------------------------------------*;

libname in        "&root./data/" ; /*input data*/ 
libname out       "&root./output/test_cahps50" ; /*output data*/
libname library   "&root./data/" ; /*path for the formats file*/

*--------------------------------------------------------------------------*
| Global Options Assigned Below                                            |
*--------------------------------------------------------------------------*;

options pagesize = 65
        linesize = 90
        pageno   = 1
		mprint
        noovp
        nonumber
        nodate
        nomprint
        nomlogic
		fmtsearch = (library.formats)
        ;
run ;

*--------------------------------------------------------------------------*
|   Clear all titles and footnotes                                         |
*--------------------------------------------------------------------------*;

title ;
footnote ;


*--------------------------------------------------------------------------*
|  Macro Name : nowbox                                                     |
|  Usage      : %nowbox (logtext = Your text here)                         |
|  Purpose    :                                                            |
|     Assign the local variable &now the current system date and time      |
|     and place a time stamp line into the current log.                    |
*--------------------------------------------------------------------------*;

%macro nowbox (logtext= ** Time Stamp **) ;
   %local now ;
   %let now = %sysfunc(date(),worddatx32.) at %sysfunc(time(),time9.) ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
   %put &logtext &now ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
%mend nowbox ;


%nowbox ( logtext= Begin &FileName version &Version ) ;

*--------------------------------------------------------------------------*
| Begin Preparation of data set for CAHPS macro                            |
*--------------------------------------------------------------------------*;

data test (drop = i);
   set in.test_cahps50_data ;

*--------------------------------------------------------------------------*
| Recode a numeric plan variable to character                              |
*--------------------------------------------------------------------------*;

   length plan $ 20 ;

   if      planid in ( 1 )    then plan = 'PRACTICE_A_URBAN' ;
   else if planid in ( 2 )    then plan = 'PRACTICE_B_URBAN' ;
   else if planid in ( 3 )    then plan = 'PRACTICE_C_URBAN' ;
   else if planid in ( 4 )    then plan = 'PRACTICE_B_RURAL' ;
   else if planid in ( 5 )    then plan = 'PRACTICE_C_RURAL' ;
   else plan = '  '; 

   label
   plan = "PLAN: Reporting Entity";  
   
*--------------------------------------------------------------------------*
| Recode dichotomous, yes/no, variables from 1/2 to 1/0                    |
*--------------------------------------------------------------------------*;

   array org q05    q26;
   array rec q05_re q26_re;

   do i = 1 to dim ( rec ) ;
      if org [i] in (1, 2) then rec [i] = 2 - org [i] ;
      else                      rec [i] = . ;
   end ;

   label
   q05_re = "RECODED q05: Last 6 mths, make appt for an illness, injury with provider" 
   q26_re = "RECODED q26: Your gender"
   ;

*---------------------------------------------------------------------------*
| Reverse code variables for which excellent =1 to be 5 and poor = 5 to be 1|
*---------------------------------------------------------------------------*;

   array org2 q23    q24;
   array rev  q23_re q24_re;

   do i = 1 to dim ( rev ) ;
      if org2 [i] in (1, 2, 3, 4, 5) then rev [i] = 6 - org2 [i] ;
      else                                rev [i] = . ;
   end ;

   label
   q23_re = "REVERSE q23: Rate overall general health"                                 
   q24_re = "REVERSE q24: Rate overall mental health"
   ;
  
*--------------------------------------------------------------------------*
| Clean variables age (q25), and education(q27)                            |
*--------------------------------------------------------------------------*;

   if q25 not in (1, 2, 3, 4, 5, 6, 7)    then q25 = . ;
   if q27 not in (1, 2, 3, 4, 5, 6)       then q27 = . ;


*--------------------------------------------------------------------------*
| Create dichotomous variables                                             |
*--------------------------------------------------------------------------*;

   /*age*/

  if q25 > 0 then do; 

       age1824 = 0; 
       age2534 = 0; 
       age3544 = 0;
       age4554 = 0; 
       age5564 = 0; 
       age6574 = 0;   
       age75   = 0;

   end;

   if q25 = 1 then age1824 = 1; 
   if q25 = 2 then age2534 = 1; 
   if q25 = 3 then age3544 = 1; 
   if q25 = 4 then age4554 = 1; 
   if q25 = 5 then age5564 = 1; 
   if q25 = 6 then age6574 = 1; 
   if q25 = 7 then age75   = 1; 
 
   label
   age1824 = "Age18-24 - 1/0"
   age2534 = "Age25-34 - 1/0"
   age3544 = "Age35-44 - 1/0"
   age4554 = "Age45-54 - 1/0"
   age5564 = "Age55-64 - 1/0"
   age6574 = "Age65-74 - 1/0"
   age75   = "Age75 above - 1/0"
   ;

   /*education*/

   if q27 > 0 then do;     

       less_8th = 0; 
       some_hs  = 0; 
       hs_grad  = 0; 
       somecoll = 0; 
       collgrad = 0; 
       collmore = 0; 

   end;

   if q27 = 1 then less_8th = 1;  
   if q27 = 2 then some_hs  = 1;  
   if q27 = 3 then hs_grad  = 1;  
   if q27 = 4 then somecoll = 1;  
   if q27 = 5 then collgrad = 1;  
   if q27 = 6 then collmore = 1;  

   label
   less_8th = "Education Less Than 8th - 1/0" 
   some_hs  = "Education Some HS - 1/0" 
   hs_grad  = "Education HS Grad - 1/0" 
   somecoll = "Education Some College - 1/0" 
   collgrad = "Education College Grad - 1/0" 
   collmore = "Education College More - 1/0" 
   ;

   /*general health status*/

   if q23_re > 0 then do;     

       ghs_poor = 0; 
       ghs_fair = 0; 
       ghs_good = 0; 
       ghs_vygd = 0; 
       ghs_exce = 0; 

   end;

   if q23_re = 1 then ghs_poor = 1;  
   if q23_re = 2 then ghs_fair = 1;  
   if q23_re = 3 then ghs_good = 1;  
   if q23_re = 4 then ghs_vygd = 1;  
   if q23_re = 5 then ghs_exce = 1;  
   
   label
   ghs_poor = "REVERSE GHS Poor - 1/0"
   ghs_fair = "REVERSE GHS Fair - 1/0"
   ghs_good = "REVERSE GHS Good - 1/0"
   ghs_vygd = "REVERSE GHS Very Good - 1/0"
   ghs_exce = "REVERSE GHS Excellent - 1/0"
   ;
 
   /*mental health status*/

   if q24_re > 0 then do;     

       mhs_poor = 0; 
       mhs_fair = 0; 
       mhs_good = 0; 
       mhs_vygd = 0; 
       mhs_exce = 0; 

   end;

   if q24_re = 1 then mhs_poor = 1;  
   if q24_re = 2 then mhs_fair = 1;  
   if q24_re = 3 then mhs_good = 1;  
   if q24_re = 4 then mhs_vygd = 1;  
   if q24_re = 5 then mhs_exce = 1;  

   label
   mhs_poor = "REVERSE MHS Poor - 1/0"
   mhs_fair = "REVERSE MHS Fair - 1/0"
   mhs_good = "REVERSE MHS Good - 1/0"
   mhs_vygd = "REVERSE MHS Very Good - 1/0"
   mhs_exce = "REVERSE MHS Excellent - 1/0"
   ;
       
run ;

data in.test_cahps50_data_recoded;
   set test;
run;

