*--------------------------------------------------------------------------*;
%let ProgramName = _3A_Test_cahps50 ;
%let Extension   = sas ;
%let Filename    = &ProgramName..&Extension ;
%let Version     = 5.0 ;
%let Root        = /data/cahps/analysis_program/version5.0 ; /*add directory*/
%let ProgramPath = /programs/ ; /*add directory where your program is located*/
%let Created     = /*created date here*/ ;
%let Modified    = /*modified date here*/ ;
%let Author      = /*your name here*/ ;
%let Type        = Program ;

***********
* Purpose *
     Program to test the functionality of the CAHPS 5.0 macro.  The data
     set, test, contains fictitious data for Dichotomous, Overall Rating
     scale (0 - 10), How Often scale (1 - 4), Problem Scale (1 - 3) and
     adjuster variables.  
*--------------------------------------------------------------------------*;
%let Updated  = dd-mmm-yyyy ;
%let By_Whom  = ;
**********
* Reason *

*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
|  Library and Filename References                                         |
|     in       -  SAS data set to be used as input.                        |
|     ** OUT is required by the CAHPS macro **                             |
|     out      -  Permanent SAS data sets created by Macro stored here.    |
|     library  -  Formats are stored.                                      |
|     logfile  -  Path and filename for the SAS log file.                  |
|     outfile  -  Path and filename for storing the SAS procedure outputs. |
*--------------------------------------------------------------------------*;

libname in        "&root./data/" ; /*input data*/ 
libname out       "&root./output/test_cahps50" ; /*output data*/
libname library   "&root./data/" ; /*formats*/

/*NOTE: (OPTION)filenames logfile and outfile stated below are not required 
to use unless the user wants to save the log and printed results to 
a specified location*/
 
filename logfile  "&root./output/logs/&ProgramName..log" ; /*SAS log file*/
filename outfile  "&root./output/&ProgramName..txt" ; /*SAS procedure output*/

*--------------------------------------------------------------------------*
| Global Options Assigned Below                                            |
*--------------------------------------------------------------------------*;

options pagesize = 65
        linesize = 90
        pageno   = 1
		mprint
        noovp
        nonumber
        nodate
        nomprint
        nomlogic
		fmtsearch = (library.formats)
        ;
run ;


*--------------------------------------------------------------------------*
| Redirect output and logs to the file referencd by outfile and logfile.   |
*--------------------------------------------------------------------------*;
/*NOTE: NO need to use if filenames logfile and outfile above are not assigned*/

proc printto print = outfile new /*path for filename "outfile"*/
             log   = logfile new /*path for filename "logfile"*/
             ;
run;

*--------------------------------------------------------------------------*
|   Clear all titles and footnotes                                         |
*--------------------------------------------------------------------------*;

title ;
footnote ;


*--------------------------------------------------------------------------*
|  Macro Name : nowbox                                                     |
|  Usage      : %nowbox (logtext = Your text here)                         |
|  Purpose    :                                                            |
|     Assign the local variable &now the current system date and time      |
|     and place a time stamp line into the current log.                    |
*--------------------------------------------------------------------------*;

%macro nowbox (logtext= ** Time Stamp **) ;
   %local now ;
   %let now = %sysfunc(date(),worddatx32.) at %sysfunc(time(),time9.) ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
   %put &logtext &now ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
%mend nowbox ;


%nowbox ( logtext= Begin &FileName version &Version ) ;

*--------------------------------------------------------------------------*
| Create a temporary analytical data set.                                  |
*--------------------------------------------------------------------------*;

data test (drop = i);
   set in.test_cahps50_data_recoded ;
run;

*--------------------------------------------------------------------------*
| Include and compile needed macros                                        |
*--------------------------------------------------------------------------*;

%include "/data/cahps/macros/Macro_cahps50.sas" ; /*include the macro program file*/

*--------------------------------------------------------------------------*
| Execute cahps macro - Dichotomous Scale                                  |
*--------------------------------------------------------------------------*;

/*Single item with age and education adjusted*/ 
%cahps(
       var       = q05_re,  /*Name of outcome variable*/
       vartype   = 1,       /*Set a type of variable: 1= dichotomous scale(1/0)*/ 
       name      = Make appt for an illness, /*Labe the outcome variable*/ 
       adjuster  = age1824 age2534 age3544 age5564 age6574 age75  
                   less_8th some_hs somecoll collgrad collmore,/*List case-mix variables*/
       adultkid  = 3,       /*Specify how to analyze child and adjult surveys: 3= analyze adult data only*/
       adj_bars  = 1,       /*Flag if frequency bars to be case-mix adjusted*/
       bar_stat  = 1,       /*Flag if case-mix adjusted frequency bars to be saved*/
       impute    = 1,       /*Flag if missing case-mix adjusters to be imputed*/ 
       outregre  = 1,       /*Flag if regression output text to be saved*/   
       dataset   = test,    /*Name of input data*/
       outname   = illness, /*Name used for output dataset*/
	   wt_type   = 0        /*Number of respondents used as weight for case-mix coefficients*/
       ) ;

*--------------------------------------------------------------------------*
| Executes cahps macro - Rating Scale                                      |
*--------------------------------------------------------------------------*;

/*No adjusters assigned, unweighted overall mean*/
%cahps(
       var        = q18,      /*Name of outcome variable*/
       vartype    = 2,        /*Set a type of variable: 2= rating scale(0 - 10)*/ 
       name       = Rate Provider,/*Label the outcome variable*/
       adjuster   =  ,        /*Leave as a blank if no adjusters needed*/ 
       adultkid   = 3,        /*Specify how to analyze child and adjult surveys: 3= analyze adult data only*/
       dataset    = test,     /*Name of the input data*/
	   overall_wt = 0,        /*Flag if 1 = weighted/0 = not weighted overall mean*/
       outname    = rprov     /*Name used for output dataset*/
       ) ;

*--------------------------------------------------------------------------*
| Executes cahps macro - Composite Items                                   |
*--------------------------------------------------------------------------*;

/*provider composite with age and general health status*/
%cahps(
       var       = q11 q12 q14 q15, /*List of composite items*/
       vartype   = 3,               /*Set a type of variable: 3= how often scale(1 - 4)*/ 
       name      = MD composite,    /*Label the composite*/
	   adjuster  = age1824 age2534 age3544 age5564 age6574 age75 
                   ghs_exce ghs_vygd ghs_fair ghs_poor, /*List case-mix adjusted variables*/
       adj_bars  = 1,       /*Flag for the adjusted frequency bar*/
       bar_stat  = 1,       /*Flag if case-mix adjusted frequency bars to be saved*/
       adultkid  = 3,       /*Specify how to analyze child and adjult surveys: 3= analyze adult data only*/
       impute    = 1,       /*Flag if missing case-mix adjusters to be imputed*/
       even_wgt  = 1,       /*Equal weight option is applied to calculate the composite mean*/ 
       dataset   = test,    /*Name of input data*/
	   proc_type = 1,       /*PROC SURVEYREG used to run a model*/
       outname   = md_comp  /*Name used for output dataset*/
       ) ;

%nowbox (logtext= End &FileName version &Version ) ;

run ;

*--------------------------------------------------------------------------*
|  Reset the log and output files back to the defaults                     |
*--------------------------------------------------------------------------*;

proc printto ;
run ;

filename _all_ clear ;

