*--------------------------------------------------------------------------*;
%let ProgramName = _3B_Test_cahps50_stratified ;
%let Extension   = sas ;
%let Filename    = &ProgramName..&Extension ;
%let Version     = 5.0 ;
%let Root        = /data/cahps/analysis_program/version5.0 ; /*add directory*/
%let ProgramPath = /programs/ ; /*add directory where your program is located*/
%let Created     = /*created date here*/ ;
%let Modified    = /*modified date here*/ ;
%let Author      = /*your name here*/ ;
%let Type        = Program ;


***********
* Purpose *
     Program to test the functionality of the CAHPS 5.0 macro.  The data
     set, test, contains fictitious data for Dichotomous, Overall Rating
     scale (0 - 10), How Often scale (1 - 4), Problem Scale (1 - 3) and
     adjuster variables.  
*--------------------------------------------------------------------------*;
%let Updated  = dd-mmm-yyyy ;
%let By_Whom  = ;
**********
* Reason *

*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
|  Library and Filename References                                         |
|     in       -  SAS data set to be used as input.                        |
|     ** OUT is required by the CAHPS macro **                             |
|     out      -  Permanent SAS data sets created by Macro stored here.    |
|     library  -  Formats are stored.                                      |
|     logfile  -  Path and filename for the SAS log file.                  |
|     outfile  -  Path and filename for storing the SAS procedure outputs. |
*--------------------------------------------------------------------------*;

libname in        "&root./data/" ; /*input data*/ 
libname out       "&root./output/test_cahps50_stratified" ; /*output data*/
libname library   "&root./data/" ; /*formats*/

filename plan_dat "&root./data/plandtal.dat" ; /*assign filename for stratified*/

/*NOTE: Note: filenames logfile and outfile stated below are required 
to use unless the user wants to save the log and printed results to 
a specified location*/
 
filename logfile  "&root./output/logs/&ProgramName..log" ; /*SAS log file*/
filename outfile  "&root./output/&ProgramName..txt" ; /*SAS procedure output*/

*--------------------------------------------------------------------------*
| Global Options Assigned Below                                            |
*--------------------------------------------------------------------------*;

options pagesize = 65
        linesize = 90
        pageno   = 1
		mprint
        noovp
        nonumber
        nodate
        nomprint
        nomlogic
		fmtsearch = (library.formats)
        ;
run ;

*--------------------------------------------------------------------------*
| Redirect output and logs to the file referencd by outfile and logfile.   |
*--------------------------------------------------------------------------*;
/*NOTE: NO need to use if filenames logfile and outfile above are not assigned*/

proc printto print = outfile new /*path for filename "outfile"*/
             log   = logfile new /*path for filename "logfile"*/
             ;
run;

*--------------------------------------------------------------------------*
|   Clear all titles and footnotes                                         |
*--------------------------------------------------------------------------*;

title ;
footnote ;


*--------------------------------------------------------------------------*
|  Macro Name : nowbox                                                     |
|  Usage      : %nowbox (logtext = Your text here)                         |
|  Purpose    :                                                            |
|     Assign the local variable &now the current system date and time      |
|     and place a time stamp line into the current log.                    |
*--------------------------------------------------------------------------*;

%macro nowbox (logtext= ** Time Stamp **) ;
   %local now ;
   %let now = %sysfunc(date(),worddatx32.) at %sysfunc(time(),time9.) ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
   %put &logtext &now ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
%mend nowbox ;

%nowbox ( logtext= Begin &FileName version &Version ) ;

*--------------------------------------------------------------------------*
| Begin Preparation of data set for CAHPS macro                            |
*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
| 1. Create plandat.dat                                                    |
|                                                                          |
|  Sample                                                                  |
|  PRACTICE_A_URBAN PRACTICE_A 5000  Northeast                             |
|  PRACTICE_B_URBAN PRACTICE_B 8000  Northeast                             |
|  PRACTICE_C_URBAN PRACTICE_C 15000 South                                 |
|  PRACTICE_B_RURAL PRACTICE_B 2000  Northeast                             |
|  PRACTICE_C_RURAL PRACTICE_C 3000  South                                 |
*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
| Sort the test data set and keep only unique values of the plan numbers.  |
*--------------------------------------------------------------------------*;

proc sort data = in.test_cahps50_data_recoded ( keep = planid 
                             where = ( planid ne . ))
          out  = test 
          nodupkey
          ;
   by planid ;
run ;

proc print data = test;
run;

data _null_ ;
   set test ;
   file plan_dat ;

   length planstra $ 20 
          planname $ 20
          stratwgt $ 10
          subset   $ 20
   ;

*--------------------------------------------------------------------------*
| Assign the Strat names and weights.                                      |
*--------------------------------------------------------------------------*;

   select ( planid ) ;
      when ( 1 ) do ;
         planstra = 'PRACTICE_A_URBAN' ;
         stratwgt = '5000' ;
      end ;
      when ( 2 ) do ;
         planstra = 'PRACTICE_B_URBAN' ;
         stratwgt = '8000' ;
      end ;
      when ( 3 ) do ;
         planstra = 'PRACTICE_C_URBAN' ;
         stratwgt = '15000' ;
      end ;
      when ( 4 ) do ;
         planstra = 'PRACTICE_B_RURAL' ;
         stratwgt = '2000' ;
      end ;
      when ( 5 ) do ;
         planstra = 'PRACTICE_C_RURAL' ;
         stratwgt = '3000' ;
      end ;
      otherwise do ;
         planstra = '???' ;
         stratwgt = '0' ;
      end ;
   end ;
   
*--------------------------------------------------------------------------*
| Assign the Plan names.                                                   |
*--------------------------------------------------------------------------*;

   select ( planid ) ;
      when ( 1 )      planname = 'PRACTICE_A' ;
      when ( 2, 4 )   planname = 'PRACTICE_B' ;
      when ( 3, 5 )   planname = 'PRACTICE_C' ;
      otherwise       planname = '???' ;
   end ;

*--------------------------------------------------------------------------*
| Assign the Subset Names                                                  |
*--------------------------------------------------------------------------*;

   select ( planid ) ;
      when ( 1, 2, 4 ) subset = 'Northeast' ;
      when ( 3, 5 )    subset = 'South' ;
      otherwise        subset = '???' ;
   end ;
   
   putline = planstra || " " || planname || " " || stratwgt || " " || subset ;
   put putline ;
run;

*--------------------------------------------------------------------------*
| 2. Prepare for analytical data                                           |
*--------------------------------------------------------------------------*;

data test2 (drop = i);
   set in.test_cahps50_data_recoded ;

run ;

*--------------------------------------------------------------------------*
| ** End Preparation of data set for CAHPS macro **                         |
*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
| Include and compile needed macros.                                       |
*--------------------------------------------------------------------------*;
%include "/data/cahps/macros/Macro_cahps50.sas" ; /*add the macro program*/

/*NOTE: Set WGTDATA = 2 to output the stratified result. The stratified output 
dataset is stored in SW&OUTNAME.sas7bdat. Also, select a SUBSET option 
(2=global case-mix model for each stratified group, 3=subset case-mix model for
each stratified group).*/

/*Rating item with adjuster and missing case-mix imputed*/
/*Subset case-mix model*/

%cahps(
       var        = q18,    /*Name of the rating variable*/
       vartype    = 2,      /*Set a type of variable: 2= rating scale(0 - 10)*/ 
       name       = Rate Provider, /*Label the output variable*/
       adjuster   = q25 q23_re ,  /*List of case-mix variables*/
       adultkid   = 3,      /*Specify how to analyze child and adult surveys: 3= analyze adult data only*/ 
	   adj_bars   = 1,      /*Flag if frequency bars to be case-mix adjusted*/
	   bar_stat   = 0,      /*Flag if case-mix adjusted to be saved*/
	   wgtdata    = 2,      /*Weight strata: 2 = stratified weighting performed */
       subset     = 3,      /*Subset case-mix model - North and South */
       impute     = 1,      /*Flag if missing case-mix adjusters to be imputed*/ 
       dataset    = test2,  /*Name of input data*/
       outname    = rprov   /*Name used for output dataset*/
	    ) ;


/*Subset = 2 and wgtdata = 2 for composite case*/
%cahps(
       var       = q11 q12 q14 q15,/*List of composite items*/
       vartype   = 3,              /*Set a type of variable: 3= how often scale(1 - 4)*/ 
       name      = MD composite,   /*Label the composite name*/
	   adjuster  = age1824 age2534 age3544 age5564 age6574 age75 
                   ghs_exce ghs_vygd ghs_fair ghs_poor,/*List case-mix adjusted variables*/
       adj_bars  = 1,      /*Flag if the frequency bar to be case-mix adjusted*/
       bar_stat  = 1,      /*Flag if the case-mix adjusted to be saved*/
       adultkid  = 3,      /*Specifies how to analyze child and adult surveys: 3= analyze adult data only*/
	   wgtdata   = 2,      /*Weight strata: 2 = Combine strata, weighting */
       subset    = 2,      /*Global case mix model with centered means for subsets*/
       impute    = 1,      /*Flag if missing case-mix adjusters to be imputed*/ 
       even_wgt  = 1,      /*Item weight is applied for the composite mean*/ 
       dataset   = test2,  /*Name of the input data*/
	   proc_type = 1,      /*PROC SURVEYREG used to run a model*/
       outname   = md_comp /*Name used for output dataset*/
       ) ;


*--------------------------------------------------------------------------*
|  Reset the log and output files back to the defaults                     |
*--------------------------------------------------------------------------*;

proc printto ;
run ;

filename _all_ clear ;

